@@ -275,6 +275,14 @@ If you want to allow those protocols, change the incoming PR to look more like t
         importance="High",
         guidance_explained="This change may disable a feature that was left on purpose. Moreover the rule added may be framework specific.",
     ),
+    "invert-boolean-check": DocMetadata(
+        importance="Low",
+        guidance_explained="We believe this replacement is safe and should not result in any issues.",
+    ),
+    "timezone-aware-datetime": DocMetadata(
+        importance="Medium",
+        guidance_explained="This change makes your code more accurate with regards to timezones. However, it's possible you wish to specify a different timezone for your application needs.",
+    ),
 }
 DEFECTDOJO_CODEMODS = {
     "django-secure-set-cookie": DocMetadata(
@@ -310,6 +318,8 @@ SONAR_CODEMOD_NAMES = [
     "django-model-without-dunder-str",
     "break-or-continue-out-of-loop",
     "disable-graphql-introspection",
+    "invert-boolean-check",
+    "timezone-aware-datetime",
 ]
 SONAR_CODEMODS = {
     name: DocMetadata(
@@ -318,6 +328,17 @@ SONAR_CODEMODS = {
         need_sarif="Yes (Sonar)",
     )
     for name in SONAR_CODEMOD_NAMES
+} | {
+    "secure-cookie": DocMetadata(
+        importance="Medium",
+        guidance_explained="Our change provides the most secure way to create cookies in Flask. However, it's possible you have configured your Flask application configurations to use secure cookies. In these cases, using the default parameters for `set_cookie` is safe.",
+        need_sarif="Yes (Sonar)",
+    ),
+    "use-secure-protocols": DocMetadata(
+        importance="High",
+        guidance_explained="While secure protocols are widely supported by a variety of application and server software, it may require explicit configuration to support those protocols.",
+        need_sarif="Yes (Sonar)",
+    ),
 }
 
 SEMGREP_CODEMOD_NAMES = [
