@@ -38,8 +38,10 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
         results = {
             "runs": [
                 {
+                    "tool": {"driver": {"name": "Semgrep OSS"}},
                     "results": [
                         {
+                            "guid": "b796b74b-275c-4785-b341-76170b43f6d4",
                             "fingerprints": {"matchBasedId/v1": "1932"},
                             "locations": [
                                 {
@@ -65,8 +67,8 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
             tmpdir,
             input_code,
             expected_output,
-            results=json.dumps(results),
             num_changes=4,
+            results=json.dumps(results),
         )
 
     def test_multiple(self, tmpdir):
@@ -108,12 +110,76 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
             else:
                 return [1, 2, float(tid), 3]
         """
+        expected_diff_per_change = [
+            """\
+--- 
++++ 
+@@ -2,7 +2,10 @@
+     tid = request.POST.get("tid")
+     some_list = [1, 2, 3, float('nan')]
+ 
+-    float(tid) in some_list
++    if tid.lower() == "nan":
++        raise ValueError
++    else:
++        float(tid) in some_list
+ 
+     z = [1, 2, complex(tid), 3]
+ 
+""",
+            """\
+--- 
++++ 
+@@ -4,7 +4,10 @@
+ 
+     float(tid) in some_list
+ 
+-    z = [1, 2, complex(tid), 3]
++    if tid.lower() == "nan":
++        raise ValueError
++    else:
++        z = [1, 2, complex(tid), 3]
+ 
+     x = [float(tid), 1.0, 2.0]
+ 
+""",
+            """\
+--- 
++++ 
+@@ -6,6 +6,9 @@
+ 
+     z = [1, 2, complex(tid), 3]
+ 
+-    x = [float(tid), 1.0, 2.0]
++    if tid.lower() == "nan":
++        raise ValueError
++    else:
++        x = [float(tid), 1.0, 2.0]
+ 
+     return [1, 2, float(tid), 3]
+""",
+            """\
+--- 
++++ 
+@@ -8,4 +8,7 @@
+ 
+     x = [float(tid), 1.0, 2.0]
+ 
+-    return [1, 2, float(tid), 3]
++    if tid.lower() == "nan":
++        raise ValueError
++    else:
++        return [1, 2, float(tid), 3]
+""",
+        ]
 
         results = {
             "runs": [
                 {
+                    "tool": {"driver": {"name": "Semgrep OSS"}},
                     "results": [
                         {
+                            "guid": "6470e0a8-2eeb-4268-8677-f96161207b40",
                             "fingerprints": {"matchBasedId/v1": "1fdbd5a"},
                             "locations": [
                                 {
@@ -140,6 +206,7 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
                             "ruleId": "python.django.security.nan-injection.nan-injection",
                         },
                         {
+                            "guid": "b3056d9a-1618-40be-bf5e-989278305cf0",
                             "fingerprints": {"matchBasedId/v1": "1fdbd5a"},
                             "locations": [
                                 {
@@ -166,6 +233,7 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
                             "ruleId": "python.django.security.nan-injection.nan-injection",
                         },
                         {
+                            "guid": "3356587c-dd3a-49e1-baee-0aafc0a91511",
                             "fingerprints": {"matchBasedId/v1": "1fdbd5a"},
                             "locations": [
                                 {
@@ -192,6 +260,7 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
                             "ruleId": "python.django.security.nan-injection.nan-injection",
                         },
                         {
+                            "guid": "626d3911-ed0b-414d-a2c9-af2245b0baee",
                             "fingerprints": {"matchBasedId/v1": "1fdbd5a"},
                             "locations": [
                                 {
@@ -225,8 +294,9 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
             tmpdir,
             input_code,
             expected_output,
+            expected_diff_per_change,
+            num_changes=4,
             results=json.dumps(results),
-            num_changes=16,
         )
 
     def test_once_nested(self, tmpdir):
@@ -247,8 +317,10 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
         results = {
             "runs": [
                 {
+                    "tool": {"driver": {"name": "Semgrep OSS"}},
                     "results": [
                         {
+                            "guid": "60e089cd-472e-489e-a264-cfc6e33e651a",
                             "fingerprints": {"matchBasedId/v1": "asdfg"},
                             "locations": [
                                 {
@@ -283,8 +355,8 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
             tmpdir,
             input_code,
             expected_output,
-            results=json.dumps(results),
             num_changes=4,
+            results=json.dumps(results),
         )
 
     def test_twice_nested(self, tmpdir):
@@ -304,8 +376,10 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
         results = {
             "runs": [
                 {
+                    "tool": {"driver": {"name": "Semgrep OSS"}},
                     "results": [
                         {
+                            "guid": "014e3945-144d-4c28-960b-4dd09f2a2b8f",
                             "fingerprints": {"matchBasedId/v1": "q324"},
                             "locations": [
                                 {
@@ -340,8 +414,8 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
             tmpdir,
             input_code,
             expected_output,
-            results=json.dumps(results),
             num_changes=4,
+            results=json.dumps(results),
         )
 
     def test_direct_source(self, tmpdir):
@@ -359,8 +433,10 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
         results = {
             "runs": [
                 {
+                    "tool": {"driver": {"name": "Semgrep OSS"}},
                     "results": [
                         {
+                            "guid": "d0540cd9-b999-4756-8392-ca2702e94438",
                             "fingerprints": {"matchBasedId/v1": "asdtg"},
                             "locations": [
                                 {
@@ -395,8 +471,8 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
             tmpdir,
             input_code,
             expected_output,
-            results=json.dumps(results),
             num_changes=4,
+            results=json.dumps(results),
         )
 
     def test_binop(self, tmpdir):
@@ -416,8 +492,10 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
         results = {
             "runs": [
                 {
+                    "tool": {"driver": {"name": "Semgrep OSS"}},
                     "results": [
                         {
+                            "guid": "33ffdd04-0f27-475c-8c11-2405e9b77526",
                             "fingerprints": {"matchBasedId/v1": "asd2"},
                             "locations": [
                                 {
@@ -452,8 +530,8 @@ class TestSemgrepNanInjection(BaseSASTCodemodTest):
             tmpdir,
             input_code,
             expected_output,
-            results=json.dumps(results),
             num_changes=4,
+            results=json.dumps(results),
         )
 
 
